{% extends "base.html" %}

{% block page_content %}
    <!-- Header -->
     <div class="card">
        <div class="card-body">
            <h2 data-toggle="tooltip" class="card-title" style="text-align: center;"> Select Qresp node to search </h2>
                    <form action="{{ url_for('search') }}" method="post" class="text-center">
                        <select name="serversList" id="serversList" class="selectpicker show-tick form-control"
                                data-width="auto" data-actions-box="true" multiple data-live-search="true">
                            {% for server in serverslist %}
                                <option value="{{ server.qresp_server_url }}">{{ server.qresp_server_url }}</option>
                            {% endfor %}
                        </select>
                        <input type="submit" id="btnSearch"
                                       name="general_search_button" value="Search"
                                       class="btn btn-theme-colored btn-lg m-0" style="font-weight: bold;">
                    </form>
               <div style="padding-top: 3rem;">
                    <h4 class="text-center">Qresp | Explorer allows you to
                    search for paper contents and to view and download the data organized in the paper.</h4>
                </div>
             </div>
        </div>
    </div>



















        <script type="text/javascript">
        window.ga=window.ga||function(){(ga.q=ga.q||[]).push(arguments)};ga.l=+new Date;
        ga('create', 'UA-126882431-1', 'auto');
        ga('send', 'pageview');
    </script>
    <script async src='https://www.google-analytics.com/analytics.js'> </script>


{% endblock %}