{% extends "base_curator.html" %}

{% block page_content %}

    {% from "_formhelpers.html" import render_field %}
    <div class="card">
        <div class="card-body">
            <h3 data-toggle="tooltip" title="This step defines the location of the remote server where the paper content is organized and  stored. The paper will be accessed by establishing an SSH connection using the credentials inserted below. Username and password will not be saved." class="card-title text-center"> Connect to the server where the paper content is located </h3>
            <div class="alert alert-success fade" id="bsalert" style="margin-top:0.1rem;margin-bottom:0.1rem;">
                        <strong>Please check your phone!</strong>
                        <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
            </div>
            <form method="post" action="server">
                        <input type="hidden" name="csrf_token" value="{{ csrf_token() }}"/>
                        {{ render_field(form.serverName) }}
                        {{ render_field(form.username) }}
                        {{ render_field(form.password) }}
                        {{ render_field(form.isDUOAuth) }}
                       <span class="input-group-btn">
                            <input type="submit" id="btnServer"
                                   value="Continue"
                                   class="btn btn-theme-colored btn-lg m-0"
                                   style="font-weight: bold; height: 50px;">
                           <input type="button" id="btnSkip"
                                   value="Skip"
                                   class="btn btn-theme-colored btn-lg m-0"
                                   style="font-weight: bold; height: 50px;" onclick="window.location='/project';">
                       </span>
                    </form>
        </div>
    </div>
    <script src="{{ url_for('static', filename='./javascript/modules/server.js') }}"></script>
        <script type="text/javascript">
        window.ga=window.ga||function(){(ga.q=ga.q||[]).push(arguments)};ga.l=+new Date;
        ga('create', 'UA-126882431-1', 'auto');
        ga('send', 'pageview');
    </script>
    <script async src='https://www.google-analytics.com/analytics.js'> </script>

{% endblock %}